# -*- coding: utf-8 -*-
#
# Copyright (c) 2020, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#

from __future__ import absolute_import, division, print_function, unicode_literals

import sys
import argparse
import webbrowser
import os.path
import oser
import platform

if sys.argv[0].endswith("__main__.py"):  # pragma: no cover
    sys.argv[0] = "python -m oser"

if sys.argv[0].endswith("oser-script.py"):  # pragma: no cover
    sys.argv[0] = "oser"


def main(args=None):
    parser = argparse.ArgumentParser(description='oser (HILSTER GmbH, http://hilster.io)')

    subparsers = parser.add_subparsers(dest="command",
                        help='the command')
    subparsers.required = True

    docs_parser = subparsers.add_parser('docs', help='open documents')

    license_parser = subparsers.add_parser('licenses', help="show open-source licenses")

    version_parser = subparsers.add_parser('version', help="show version")

    args = parser.parse_args(args=args)

    if args.command == "docs":
        url = "https://docs.hilster.io/oser/oser-{}/".format(oser.__version__)
        webbrowser.open(url)

    if args.command == "licenses":
        print(LICENSES)

    if args.command == "version":
        print("oser-{oser_version} with Python {python_version} {machine}".format(
            oser_version=oser.__version__,
            python_version=platform.python_version(),
            machine=platform.machine()
        ))

    sys.exit(0)


LICENSES = """
Open Source Licenses
====================

The Sodium Crypto library (libsodium-1.0.10, http://libsodium.org)
------------------------------------------------------------------

Copyright (c) 2013-2016
Frank Denis <j at pureftpd dot org>

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

if __name__ == "__main__":  # pragma: no cover
    main()
